/*
 * Copyright 2019 Confluent Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.confluent.kafka.secretregistry.client;

import java.util.Objects;

import io.confluent.kafka.secretregistry.client.rest.entities.Secret;

public class SecretMetadata {

  private String path;
  private String key;
  private int version;
  private String secret;

  public SecretMetadata(String path, String key, int version, String secret) {
    this.path = path;
    this.key = key;
    this.version = version;
    this.secret = secret;

  }

  public SecretMetadata(Secret secret) {
    this.path = secret.getPath();
    this.key = secret.getKey();
    this.version = secret.getVersion();
    this.secret = secret.getSecret();
  }

  public String getPath() {
    return path;
  }

  public String getKey() {
    return key;
  }

  public int getVersion() {
    return version;
  }

  public String getSecret() {
    return secret;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    SecretMetadata that = (SecretMetadata) o;
    return version == that.version
        && Objects.equals(path, that.path)
        && Objects.equals(key, that.key)
        && Objects.equals(secret, that.secret);
  }

  @Override
  public int hashCode() {
    return Objects.hash(path, key, version, secret);
  }

  @Override
  public String toString() {
    return "SecretMetadata{"
        + "path='" + path + '\''
        + ", key='" + key + '\''
        + ", version=" + version
        + ", secret='[hidden]'"
        + '}';
  }
}
