/*
 * Copyright 2019 Confluent Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.confluent.kafka.secretregistry.client;

import java.io.IOException;
import java.util.Collection;
import java.util.Map;

import io.confluent.kafka.secretregistry.client.rest.exceptions.RestClientException;

public interface SecretRegistryClient {

  int register(String path, String key, String secret) throws IOException, RestClientException;

  Collection<String> listAllPaths() throws IOException, RestClientException;

  Collection<String> listAllKeys(String path) throws IOException, RestClientException;

  Collection<Integer> listAllVersions(String path, String key)
      throws IOException, RestClientException;

  Collection<SecretMetadata> getAllLatest(String path) throws IOException, RestClientException;

  Collection<SecretMetadata> getAllVersions(String path, String key)
      throws IOException, RestClientException;

  SecretMetadata getLatestSecretMetadata(String path, String key)
      throws IOException, RestClientException;

  SecretMetadata getSecretMetadata(String path, String key, int version)
      throws IOException, RestClientException;

  void deletePath(String path) throws IOException, RestClientException;

  void deletePath(Map<String, String> requestProperties, String path)
      throws IOException, RestClientException;

  void deleteKey(String path, String key) throws IOException, RestClientException;

  void deleteKey(Map<String, String> requestProperties, String path, String key)
      throws IOException, RestClientException;

  void deleteVersion(String path, String key, String version)
      throws IOException, RestClientException;

  void deleteVersion(
      Map<String, String> requestProperties,
      String path,
      String key,
      String version
  )
      throws IOException, RestClientException;

  void reset();
}
