/*
 * Copyright 2019 Confluent Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.confluent.kafka.secretregistry.client.rest.entities;

import com.fasterxml.jackson.annotation.JsonProperty;

import java.util.Objects;

public class Secret implements Comparable<Secret> {

  private String path;
  private String key;
  private Integer version;
  private String secret;

  public Secret(
      @JsonProperty("path") String path,
      @JsonProperty("key") String key,
      @JsonProperty("version") Integer version,
      @JsonProperty("secret") String secret
  ) {
    this.path = path;
    this.key = key;
    this.version = version;
    this.secret = secret;
  }

  @JsonProperty("path")
  public String getPath() {
    return path;
  }

  @JsonProperty("path")
  public void setPath(String path) {
    this.path = path;
  }

  @JsonProperty("key")
  public String getKey() {
    return key;
  }

  @JsonProperty("key")
  public void setKey(String key) {
    this.key = key;
  }

  @JsonProperty("version")
  public Integer getVersion() {
    return this.version;
  }

  @JsonProperty("version")
  public void setVersion(Integer version) {
    this.version = version;
  }

  @JsonProperty("secret")
  public String getSecret() {
    return this.secret;
  }

  @JsonProperty("secret")
  public void setSecret(String secret) {
    this.secret = secret;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    Secret secret1 = (Secret) o;
    return Objects.equals(path, secret1.path)
        && Objects.equals(key, secret1.key)
        && Objects.equals(version, secret1.version)
        && Objects.equals(secret, secret1.secret);
  }

  @Override
  public int hashCode() {
    return Objects.hash(path, key, version, secret);
  }

  @Override
  public String toString() {
    return "Secret{"
        + "path='" + path + '\''
        + ", key='" + key + '\''
        + ", version=" + version
        + ", secret='[hidden]'"
        + '}';
  }

  @Override
  public int compareTo(Secret that) {
    if (this.path.compareTo(that.path) < 0) {
      return -1;
    } else if (this.path.compareTo(that.path) > 0) {
      return 1;
    }

    if (this.key.compareTo(that.key) < 0) {
      return -1;
    } else if (this.key.compareTo(that.key) > 0) {
      return 1;
    }

    if (this.version.compareTo(that.version) < 0) {
      return -1;
    } else if (this.version.compareTo(that.version) > 0) {
      return 1;
    }

    if (this.secret.compareTo(that.secret) < 0) {
      return -1;
    } else if (this.secret.compareTo(that.secret) > 0) {
      return 1;
    }
    return 0;
  }
}
